package de.thdeg.greiner.superpangworld.game.managers;

import de.thdeg.greiner.superpangworld.gameview.GameView;
import de.thdeg.greiner.superpangworld.graphics.immovable.*;
import de.thdeg.greiner.superpangworld.graphics.moveable.*;

import java.awt.*;

/**
 * The manager handling the display and passive movement of the game objects.
 */
class GameObjectManager {

    /** The GameView to display the objects */
    private GameView gameView;

    /** The game objects */
    private RoundBubble roundBubble;
    private HexagonalBubble hexBubble;
    private SpecialBubble specialBubble;
    private Harpoon harpoon;
    private LevelProgressBar levelProgressBar;
    private LevelLabel levelLabel;
    private ScoreLabel scoreLabel;
    private LivesIcon livesIcon;
    private Background background;
    private Player player;

    /**
     * Create a manager handling the display and passive movement of the game objects.
     * @param gameView the GameView
     */
    public GameObjectManager(GameView gameView){
        this.gameView = gameView;

        gameView.setColorForBlockImage('k', Color.LIGHT_GRAY);

        this.roundBubble = new RoundBubble(gameView);
        this.hexBubble = new HexagonalBubble(gameView);
        this.specialBubble = new SpecialBubble(gameView);

        this.harpoon = new Harpoon(gameView);

        this.levelProgressBar = new LevelProgressBar(gameView);
        this.levelLabel = new LevelLabel(gameView);
        this.scoreLabel = new ScoreLabel(gameView);

        this.livesIcon = new LivesIcon(gameView);

        this.background = new Background(gameView);

        this.player = new Player(gameView);

    }

    /**
     * Add the objects to the canvas and handle update their positions.
     */
    public void updateGameObjects(){
        background.addToCanvas();
        roundBubble.updatePosition();
        roundBubble.addToCanvas();
        hexBubble.updatePosition();
        hexBubble.addToCanvas();
        specialBubble.updatePosition();
        specialBubble.addToCanvas();
        harpoon.updatePosition();
        harpoon.addToCanvas();

        levelProgressBar.addToCanvas();
        levelLabel.addToCanvas();
        scoreLabel.addToCanvas();
        livesIcon.addToCanvas();

        player.addToCanvas();
    }

    /**
     * Get the player object.
     * @return the player
     */
    public Player getPlayer(){
        return player;
    }

}
